<?php
session_start();
if (!isset($_SESSION['id']) || $_SESSION['type'] !== 'prestataire') {
    header("Location: login.php");
    exit();
}

include 'config.php';
include 'header.php';
include 'sidebar.php';

$prestataire_id = $_SESSION['id'];

// Création du dossier si inexistant
$upload_dir = "uploads/documents/";
if (!is_dir($upload_dir)) {
    mkdir($upload_dir, 0777, true);
}

// Soumission des documents
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_FILES["documents"])) {
    $success = "";
    $error = "";

    foreach ($_FILES["documents"]["name"] as $key => $filename) {
        if ($_FILES["documents"]["error"][$key] === 0) {
            $nom_document = $_POST["document_nom"][$key];
            $type_document = $_POST["document_type"][$key];
            $description = $_POST["description"][$key];

            $file_name = time() . "_" . basename($filename);
            $target_file = $upload_dir . $file_name;

            if (move_uploaded_file($_FILES["documents"]["tmp_name"][$key], $target_file)) {
                $stmt = $conn->prepare("INSERT INTO documents_verification (prestataire_id, document_nom, document_type, document_path, statut, description) VALUES (?, ?, ?, ?, 'en attente', ?)");
                $stmt->bind_param("issss", $prestataire_id, $nom_document, $type_document, $target_file, $description);
                $stmt->execute();
                $stmt->close();
                $success = "Documents soumis avec succès ! En attente de vérification.";
            } else {
                $error = "Erreur lors de l'envoi du fichier : " . $filename;
            }
        } else {
            $error = "Erreur lors du téléchargement du fichier.";
        }
    }
}

// Récupération des documents soumis
$documents = $conn->query("SELECT * FROM documents_verification WHERE prestataire_id = $prestataire_id ORDER BY date_soumission DESC");

$conn->close();
?>

<div class="container-fluid mt-4">
    <h2 class="mb-4">🏆 Obtenir le Badge Prestataire Vérifié</h2>

    <?php if (isset($success) && $success): ?>
        <div class="alert alert-success"><?= $success ?></div>
    <?php endif; ?>
    <?php if (isset($error) && $error): ?>
        <div class="alert alert-danger"><?= $error ?></div>
    <?php endif; ?>

    <!-- Formulaire d'envoi de documents -->
    <form action="badge_verification.php" method="post" enctype="multipart/form-data">
        <div id="documentsContainer">
            <div class="document-group mb-3">
                <label class="form-label">Nom du document :</label>
                <input type="text" name="document_nom[]" class="form-control" required>

                <label class="form-label">Type de document :</label>
                <select name="document_type[]" class="form-control" required>
                    <option value="certification">Certification</option>
                    <option value="diplome">Diplôme</option>
                    <option value="permis">Permis</option>
                </select>

                <label class="form-label">Description :</label>
                <textarea name="description[]" class="form-control" rows="2" required></textarea>

                <label class="form-label">Télécharger le document :</label>
                <input type="file" name="documents[]" class="form-control" required>
                <hr>
            </div>
        </div>
        <button type="button" class="btn btn-secondary mb-3" onclick="addDocumentField()">➕ Ajouter un autre document</button>
        <button type="submit" class="btn btn-primary">Soumettre</button>
    </form>

    <!-- Liste des documents soumis -->
    <hr>
    <h3 class="mb-3">📂 Documents soumis</h3>
    <div class="row">
        <?php while ($row = $documents->fetch_assoc()) { ?>
            <div class="col-md-4">
                <div class="card p-3 mb-3 shadow-sm">
                    <h5><?= htmlspecialchars($row['document_nom']); ?></h5>
                    <p><b>Type :</b> <?= ucfirst($row['document_type']); ?></p>
                    <p><b>Description :</b> <?= nl2br(htmlspecialchars($row['description'])); ?></p>
                    <p><b>Statut :</b> 
                        <span class="badge bg-<?= $row['statut'] == 'validé' ? 'success' : ($row['statut'] == 'rejeté' ? 'danger' : 'warning'); ?>">
                            <?= ucfirst($row['statut']); ?>
                        </span>
                    </p>
                    <a href="<?= $row['document_path']; ?>" target="_blank" class="btn btn-outline-primary btn-sm">📂 Voir</a>
                </div>
            </div>
        <?php } ?>
    </div>
</div>

<script>
function addDocumentField() {
    const container = document.getElementById("documentsContainer");

    let html = `
        <div class="document-group mb-3">
            <label class="form-label">Nom du document :</label>
            <input type="text" name="document_nom[]" class="form-control" required>

            <label class="form-label">Type de document :</label>
            <select name="document_type[]" class="form-control" required>
                <option value="certification">Certification</option>
                <option value="diplome">Diplôme</option>
                <option value="permis">Permis</option>
            </select>

            <label class="form-label">Description :</label>
            <textarea name="description[]" class="form-control" rows="2" required></textarea>

            <label class="form-label">Télécharger le document :</label>
            <input type="file" name="documents[]" class="form-control" required>
            <hr>
        </div>
    `;
    container.insertAdjacentHTML('beforeend', html);
}
</script>

<?php include 'footer.php'; ?>
