<?php
session_start();
include 'config.php';
include 'header.php';
include 'sidebar.php';

if (!isset($_SESSION['id']) || $_SESSION['type'] !== 'client') {
    header("Location: login.php");
    exit();
}

$client_id = $_SESSION['id'];

// 🔢 Statistiques
$stats = $conn->query("
    SELECT 
        COUNT(*) AS total,
        SUM(CASE WHEN statut = 'en attente' THEN 1 ELSE 0 END) AS attente,
        SUM(CASE WHEN statut = 'valider' THEN 1 ELSE 0 END) AS valider,
        COUNT(DISTINCT s.prestataire_id) AS contactes
    FROM reservations r
    JOIN services s ON r.service_id = s.id
    WHERE r.client_id = $client_id
")->fetch_assoc();

// 🔄 Réservations pour timeline
$timeline = $conn->query("
    SELECT 
        r.date_reservation AS date_event,
        s.nom_service,
        r.statut,
        'reservation' AS type_event
    FROM reservations r 
    JOIN services s ON r.service_id = s.id 
    WHERE r.client_id = $client_id

    UNION ALL

    SELECT 
        m.date_envoi AS date_event,
        CONCAT('Message envoyé : ', SUBSTRING(m.message, 1, 50)),
        'message',
        'message'
    FROM messages m
    JOIN reservations r ON m.reservation_id = r.id
    WHERE m.expediteur_id = $client_id

    ORDER BY date_event DESC
    LIMIT 10
");
?>

<div class="container-fluid mt-4">
    <h2 class="mb-4">🎯 Tableau de bord Client</h2>

    <div class="row g-3">
        <div class="col-md-3">
            <div class="card shadow-sm text-center p-3">
                <h5>📌 Réservations Totales</h5>
                <p class="display-6 fw-bold"><?= $stats['total'] ?? 0 ?></p>
            </div>
        </div>
        <div class="col-md-3">
            <div class="card shadow-sm text-center p-3">
                <h5>⏳ En Attente</h5>
                <p class="display-6 fw-bold text-warning"><?= $stats['attente'] ?? 0 ?></p>
            </div>
        </div>
        <div class="col-md-3">
            <div class="card shadow-sm text-center p-3">
                <h5>✅ Validées</h5>
                <p class="display-6 fw-bold text-success"><?= $stats['valider'] ?? 0 ?></p>
            </div>
        </div>
        <div class="col-md-3">
            <div class="card shadow-sm text-center p-3">
                <h5>🤝 Prestataires Contactés</h5>
                <p class="display-6 fw-bold"><?= $stats['contactes'] ?? 0 ?></p>
            </div>
        </div>
    </div>

    <div class="card mt-4 p-4 shadow-sm">
        <h5 class="mb-3">📜 Activité Récente</h5>
        <ul class="list-group">
            <?php if ($timeline->num_rows > 0): ?>
                <?php while ($row = $timeline->fetch_assoc()): ?>
                    <li class="list-group-item d-flex justify-content-between align-items-start">
                        <div>
                            <?php if ($row['type_event'] === 'message'): ?>
                                <i class="fas fa-envelope text-secondary me-2"></i>
                            <?php elseif ($row['type_event'] === 'reservation'): ?>
                                <i class="fas fa-calendar-check text-primary me-2"></i>
                            <?php endif; ?>
                            <?= htmlspecialchars($row['nom_service']) ?>
                        </div>
                        <small class="text-muted"><?= date("d/m/Y H:i", strtotime($row['date_event'])) ?></small>
                    </li>
                <?php endwhile; ?>
            <?php else: ?>
                <li class="list-group-item text-muted">Aucune activité récente.</li>
            <?php endif; ?>
        </ul>
    </div>

    <div class="text-end mt-4">
        <a href="reservations_client.php" class="btn btn-outline-primary">📅 Voir toutes mes réservations</a>
        <a href="messagerie.php" class="btn btn-outline-secondary ms-2">💬 Accéder à la messagerie</a>
    </div>
</div>

<?php include 'footer.php'; ?>
