<?php
session_start();
include 'config.php';

if (!isset($_SESSION['id'])) {
    header("Location: login.php");
    exit();
}

$user_id = $_SESSION['id'];
$reservation_id = isset($_GET['reservation_id']) ? intval($_GET['reservation_id']) : 0;

// ✅ Vérification des droits
$sqlCheck = "SELECT * FROM reservations WHERE id = ? AND (client_id = ? OR service_id IN (SELECT id FROM services WHERE prestataire_id = ?))";
$stmt = $conn->prepare($sqlCheck);
$stmt->bind_param("iii", $reservation_id, $user_id, $user_id);
$stmt->execute();
$result = $stmt->get_result();
if ($result->num_rows === 0) {
    echo "<div class='alert alert-danger'>Accès refusé à cette discussion.</div>";
    exit();
}
$stmt->close();

// ✅ Envoi de message
if ($_SERVER['REQUEST_METHOD'] === 'POST' && !empty($_POST['message'])) {
    $message = htmlspecialchars($_POST['message']);

    // 🧠 Trouver l'autre participant (destinataire)
    $stmt = $conn->prepare("SELECT client_id, service_id FROM reservations WHERE id = ?");
    $stmt->bind_param("i", $reservation_id);
    $stmt->execute();
    $stmt->bind_result($client_id, $service_id);
    $stmt->fetch();
    $stmt->close();

    $stmt2 = $conn->prepare("SELECT prestataire_id FROM services WHERE id = ?");
    $stmt2->bind_param("i", $service_id);
    $stmt2->execute();
    $stmt2->bind_result($prestataire_id);
    $stmt2->fetch();
    $stmt2->close();

    $destinataire_id = ($user_id == $client_id) ? $prestataire_id : $client_id;

    $stmt = $conn->prepare("INSERT INTO messages (reservation_id, expediteur_id, destinataire_id, message) VALUES (?, ?, ?, ?)");
    $stmt->bind_param("iiis", $reservation_id, $user_id, $destinataire_id, $message);
    $stmt->execute();
    $stmt->close();
}
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <title>Discussion | ProBooker</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <script src="https://code.jquery.com/jquery-3.6.4.min.js"></script>
    <style>
        .chat-box {
            max-height: 500px;
            overflow-y: auto;
            padding: 10px;
            background-color: #f1f1f1;
            border: 1px solid #ddd;
            border-radius: 10px;
        }
        .message {
            margin-bottom: 15px;
        }
        .message .expediteur {
            font-weight: bold;
            color: #764ba2;
        }
        .message .date {
            font-size: 0.8rem;
            color: #666;
        }
    </style>
</head>
<body>
<div class="container mt-5">
    <h3 class="mb-4">💬 Discussion autour de la réservation #<?= $reservation_id ?></h3>

    <div id="chatBox" class="chat-box mb-4"></div>

    <form method="post">
        <div class="mb-3">
            <textarea name="message" class="form-control" placeholder="Écrivez votre message ici..." required></textarea>
        </div>
        <button type="submit" class="btn btn-primary">Envoyer</button>
    </form>
</div>

<script>
function chargerMessages() {
    $.get("get_messages.php", { reservation_id: <?= $reservation_id ?> }, function(data) {
        $("#chatBox").html(data);
        $("#chatBox").scrollTop($("#chatBox")[0].scrollHeight);
    });
}

// Rafraîchir automatiquement toutes les 5 secondes
setInterval(chargerMessages, 5000);

// Charger au démarrage
chargerMessages();
</script>
</body>
</html>
