<?php
session_start();
include 'header.php';
include 'sidebar.php';

if (!isset($_SESSION['id']) || $_SESSION['type'] !== 'prestataire') {
    header("Location: login.php");
    exit();
}
include 'config.php';

$prestataire_id = $_SESSION['id'];

// 📌 Ajout d'une disponibilité
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['action'])) {
    if ($_POST['action'] === 'ajouter') {
        $statut = $_POST['statut'];
        $date = $_POST['date'];

        switch ($statut) {
            case 'matin': $date_debut = $date . " 08:00:00"; $date_fin = $date . " 12:00:00"; break;
            case 'apres-midi': $date_debut = $date . " 14:00:00"; $date_fin = $date . " 18:00:00"; break;
            case 'complet': $date_debut = $date . " 08:00:00"; $date_fin = $date . " 18:00:00"; break;
            default: $date_debut = $_POST['date_debut']; $date_fin = $_POST['date_fin']; break;
        }

        $stmt = $conn->prepare("INSERT INTO disponibilites (prestataire_id, date_debut, date_fin, statut) VALUES (?, ?, ?, ?)");
        $stmt->bind_param("isss", $prestataire_id, $date_debut, $date_fin, $statut);
        $stmt->execute();
        $stmt->close();
    }

    // ❌ Suppression d'une disponibilité
    if ($_POST['action'] === 'supprimer') {
        $dispo_id = $_POST['dispo_id'];
        $conn->query("DELETE FROM disponibilites WHERE id = $dispo_id AND prestataire_id = $prestataire_id");
    }
}

// 📌 Récupération des disponibilités
$disponibilites = $conn->query("SELECT * FROM disponibilites WHERE prestataire_id = $prestataire_id");
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <title>Gérer Mes Disponibilités | ProBooker</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/fullcalendar@6.1.8/main.min.css" rel="stylesheet">
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/fullcalendar@6.1.8/index.global.min.js"></script>

</head>
<body>

    <!-- Contenu principal -->
    <div class="content">
        <h2 class="mb-4 text-center text-primary">📅 Gérer Mes Disponibilités</h2>

        <!-- Formulaire d'ajout -->
        <div class="card">
            <h3 class="mb-3">➕ Ajouter une disponibilité</h3>
            <form action="disponibilites.php" method="post">
                <input type="hidden" name="action" value="ajouter">
                <div class="row">
                    <div class="col-md-4">
                        <label class="form-label">📅 Date :</label>
                        <input type="date" name="date" class="form-control mb-2" required>
                    </div>
                    <div class="col-md-4">
                        <label class="form-label">⏳ Type :</label>
                        <select name="statut" class="form-control mb-2" required>
                            <option value="matin">☀️ Matinée (08:00 - 12:00)</option>
                            <option value="apres-midi">🌆 Après-midi (14:00 - 18:00)</option>
                            <option value="complet">📅 Journée entière (08:00 - 18:00)</option>
                            <option value="custom">⏳ Personnalisé</option>
                        </select>
                    </div>
                </div>

                <div id="custom_times" style="display: none;">
                    <label class="form-label">🔹 Début :</label>
                    <input type="datetime-local" name="date_debut" class="form-control mb-2">
                    <label class="form-label">🔹 Fin :</label>
                    <input type="datetime-local" name="date_fin" class="form-control mb-2">
                </div>

                <button type="submit" class="btn btn-primary w-100 mt-2">Ajouter</button>
            </form>
        </div>

        <!-- Calendrier -->
        <div class="card">
            <h3 class="mb-3">📆 Mon Calendrier</h3>
            <div id="calendar"></div>
        </div>

        <!-- Liste des disponibilités -->
        <div class="card">
            <h3 class="mb-3">📋 Mes Disponibilités</h3>
            <ul class="list-group">
                <?php while ($row = $disponibilites->fetch_assoc()): ?>
                <li class="list-group-item d-flex justify-content-between align-items-center">
                    <span class="text-success">
                        <?= date("d/m/Y H:i", strtotime($row['date_debut'])) . " - " . date("d/m/Y H:i", strtotime($row['date_fin'])) . " (" . ucfirst($row['statut']) . ")"; ?>
                    </span>
                    <form method="post" onsubmit="return confirm('❌ Voulez-vous vraiment supprimer cette disponibilité ?');">
                        <input type="hidden" name="dispo_id" value="<?= $row['id']; ?>">
                        <input type="hidden" name="action" value="supprimer">
                        <button type="submit" class="btn btn-danger btn-sm">🗑 Supprimer</button>
                    </form>
                </li>
                <?php endwhile; ?>
            </ul>
        </div>
    </div>

    <script>
        document.addEventListener('DOMContentLoaded', function() {
            var calendarEl = document.getElementById('calendar');
            var calendar = new FullCalendar.Calendar(calendarEl, {
                locale: 'fr',
                initialView: 'dayGridMonth',
                events: 'get_disponibilites.php',
                eventColor: "#764ba2"
            });
            calendar.render();

            document.querySelector("select[name='statut']").addEventListener("change", function() {
                document.getElementById("custom_times").style.display = this.value === "custom" ? "block" : "none";
            });
        });
    </script>

</body>
</html>
