<?php
session_start();
include 'config.php';

if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['email'])) {
    $email = $_POST['email'];
    $password = $_POST['password'];

    $sql = "SELECT id, nom, password, type, statut FROM utilisateurs WHERE email = ?";
    $stmt = $conn->prepare($sql);
    if (!$stmt) die("Erreur SQL : " . $conn->error);

    $stmt->bind_param("s", $email);
    $stmt->execute();
    $stmt->store_result();

    if ($stmt->num_rows > 0) {
        $stmt->bind_result($id, $nom, $hashed_password, $type, $statut);
        $stmt->fetch();

        if (password_verify($password, $hashed_password)) {
            if ($statut == 'actif' || $type == 'admin') {
                $_SESSION['id'] = $id;
                $_SESSION['nom'] = $nom;
                $_SESSION['type'] = $type;

                $dashboard = [
                    'client' => 'dashboard_client.php',
                    'prestataire' => 'dashboard_prestataire.php',
                    'admin' => 'dashboard_admin.php'
                ];
                header("Location: " . $dashboard[$type]);
                exit();
            } else {
                $error = "Votre compte n'est pas encore activé.";
            }
        } else {
            $error = "Mot de passe incorrect.";
        }
    } else {
        $error = "Aucun compte trouvé avec cet email.";
    }
    $stmt->close();
}
$conn->close();
?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <title>Connexion | ProBooker</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta charset="UTF-8">
    <script src="https://accounts.google.com/gsi/client" async defer></script>
    <script async defer crossorigin="anonymous" src="https://connect.facebook.net/fr_FR/sdk.js"></script>
    <script src="https://kit.fontawesome.com/a076d05399.js" crossorigin="anonymous"></script>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            height: 100vh;
            background: linear-gradient(to right, #667eea, #764ba2);
            display: flex;
            justify-content: center;
            align-items: center;
        }

        .card {
            border-radius: 10px;
            box-shadow: 0 5px 20px rgba(0,0,0,0.2);
        }

        .sidebar {
            background: #fff;
            border-radius: 10px;
            padding: 30px;
        }

        .logo {
            font-size: 1.8rem;
            font-weight: bold;
            color: #764ba2;
        }

        .social-btn {
            display: flex;
            align-items: center;
            justify-content: center;
            font-weight: 500;
            font-size: 15px;
        }

        .social-btn i {
            margin-right: 8px;
        }

        .text-link {
            font-size: 14px;
        }

        .text-link a {
            color: #764ba2;
            font-weight: 600;
            text-decoration: none;
        }

        .text-link a:hover {
            text-decoration: underline;
        }
    </style>
</head>
<body>
<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-10">
            <div class="card p-4">
                <div class="row">
                    <div class="col-md-6 sidebar text-center">
                        <h2 class="logo">ProBooker</h2>
                        <p class="text-muted">Connectez-vous pour accéder à votre espace.</p>
                        <img src="img1.png" class="img-fluid mt-3 rounded shadow-sm" alt="Login Illustration">
                    </div>
                    <div class="col-md-6">
                        <h3 class="mb-4 fw-bold">Connexion</h3>

                        <?php if (isset($error)) echo "<div class='alert alert-danger'>$error</div>"; ?>

                        <form action="login.php" method="post">
                            <div class="mb-3">
                                <label>Email :</label>
                                <input type="email" name="email" class="form-control" required>
                            </div>
                            <div class="mb-3">
                                <label>Mot de passe :</label>
                                <input type="password" name="password" class="form-control" required>
                            </div>
                            <button type="submit" class="btn btn-primary w-100">Se connecter</button>
                        </form>

                        <div class="text-center mt-3 text-link">
                            <a href="reset_password.php">🔒 Mot de passe oublié ?</a>
                        </div>

                        <!-- Réseaux sociaux -->
<div class="mt-4 text-center">
    <!-- Google Sign In -->
    <div id="g_id_onload"
         data-client_id="462216893034-dmmrtbktfplfifq2m4q8gkft26fviulf.apps.googleusercontent.com"
         data-login_uri="google_login.php"
         data-auto_prompt="false">
    </div>
    <div class="g_id_signin d-flex justify-content-center"
         data-type="standard"
         data-size="large"
         data-theme="outline"
         data-text="sign_in_with"
         data-shape="rectangular"
         data-logo_alignment="left">
    </div>

    <!-- Facebook Sign In -->
    <div class="d-flex justify-content-center mt-3">
        <a href="facebook_login.php"
           class="btn btn-outline-primary social-btn"
           style="max-width: 300px; width: 100%;">
            <i class="fab fa-facebook me-2"></i> Se connecter avec Facebook
        </a>
    </div>
</div>


                        <p class="mt-4 text-center text-link">👤 Nouveau ? <a href="register.php">Créer un compte</a></p>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
    window.fbAsyncInit = function () {
        FB.init({
            appId: '1882170775886766',
            cookie: true,
            xfbml: true,
            version: 'v19.0'
        });
    };
</script>
</body>
</html>
