<?php
session_start();
if (!isset($_SESSION['id']) || $_SESSION['type'] !== 'prestataire') {
    header("Location: login.php");
    exit();
}

include 'config.php';
include 'header.php';
include 'sidebar.php';

$prestataire_id = $_SESSION['id'];
$service_id = $_GET['id'] ?? null;

if (!$service_id) {
    echo "<div class='alert alert-danger'>Service introuvable.</div>";
    exit();
}

// Récupération du service
$stmt = $conn->prepare("SELECT * FROM services WHERE id = ? AND prestataire_id = ?");
$stmt->bind_param("ii", $service_id, $prestataire_id);
$stmt->execute();
$result = $stmt->get_result();
$service = $result->fetch_assoc();
$stmt->close();

// Mise à jour des informations
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $nom_service = $_POST['nom_service'];
    $description = $_POST['description'];
    $prix = $_POST['prix'];
    $lieu = $_POST['lieu'];

    $stmt = $conn->prepare("UPDATE services SET nom_service = ?, description = ?, prix = ?, lieu = ? WHERE id = ? AND prestataire_id = ?");
    $stmt->bind_param("ssdsii", $nom_service, $description, $prix, $lieu, $service_id, $prestataire_id);

    if ($stmt->execute()) {
        echo "<div class='alert alert-success'>Service mis à jour avec succès.</div>";
    }
    $stmt->close();
}
?>

<div class="container mt-4">
    <h2 class="text-center">✏ Modifier un Service</h2>
    <div class="card p-4">
        <form method="post">
            <label class="form-label">Nom du Service :</label>
            <input type="text" name="nom_service" class="form-control" value="<?= htmlspecialchars($service['nom_service']); ?>" required>

            <label class="form-label mt-2">Description :</label>
            <textarea name="description" class="form-control" required><?= htmlspecialchars($service['description']); ?></textarea>

            <label class="form-label mt-2">Prix (€) :</label>
            <input type="number" step="0.01" name="prix" class="form-control" value="<?= $service['prix']; ?>" required>

            <label class="form-label mt-2">Lieu :</label>
            <input type="text" name="lieu" class="form-control" value="<?= htmlspecialchars($service['lieu']); ?>" required>

            <button type="submit" class="btn btn-primary w-100 mt-3">Mettre à jour</button>
        </form>
    </div>
</div>

<?php include 'footer.php'; ?>
