<?php
session_start();
if (!isset($_SESSION['id']) || $_SESSION['type'] !== 'client') {
    header("Location: login.php");
    exit();
}
include 'config.php';
include 'sidebar.php';
include 'header.php';

$selected_specialite = isset($_GET['specialite']) ? $_GET['specialite'] : '';
$selected_ville = isset($_GET['ville']) ? $_GET['ville'] : '';

// Récupération des filtres disponibles
$specialites_result = $conn->query("SELECT DISTINCT specialite FROM utilisateurs WHERE type='prestataire' AND statut='actif' AND specialite IS NOT NULL");
$villes_result = $conn->query("SELECT DISTINCT ville FROM utilisateurs WHERE type='prestataire' AND statut='actif' AND ville IS NOT NULL");

$where = "type='prestataire' AND statut='actif'";
if (!empty($selected_specialite)) {
    $where .= " AND specialite = '" . $conn->real_escape_string($selected_specialite) . "'";
}
if (!empty($selected_ville)) {
    $where .= " AND ville = '" . $conn->real_escape_string($selected_ville) . "'";
}

$sql = "SELECT id, nom, email, photo, presentation, badge_verifie, created_at FROM utilisateurs WHERE $where";
$result = $conn->query($sql);
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <title>Liste des Prestataires | ProBooker</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <script src="https://kit.fontawesome.com/a076d05399.js" crossorigin="anonymous"></script>
    <style>
        .card {
            border-radius: 12px;
            transition: 0.3s;
            padding: 20px;
        }
        .card:hover {
            box-shadow: 0px 6px 18px rgba(0, 0, 0, 0.15);
        }
        .profile-img {
            width: 100px;
            height: 100px;
            object-fit: cover;
            border-radius: 50%;
            margin-bottom: 10px;
        }
        .verified {
            border: 2px solid #28a745;
            box-shadow: 0 0 10px rgba(40, 167, 69, 0.3);
        }
        .badge-verified {
            font-size: 0.8rem;
            color: #28a745;
            font-weight: bold;
        }
        .btn-pro {
            background-color: #764ba2;
            border: none;
        }
        .btn-pro:hover {
            background-color: #5a3c80;
        }
        .badge.bg-info {
            background-color: #17a2b8;
            font-size: 0.75rem;
        }
    </style>
</head>
<body>
<div class="content p-4">
    <h2 class="mb-4 text-center">🔍 Liste des Prestataires</h2>

    <form class="row mb-4" method="GET" id="filtreForm">
        <div class="col-md-4">
            <select name="specialite" class="form-select" onchange="document.getElementById('filtreForm').submit()">
                <option value="">-- Toutes les spécialités --</option>
                <?php while ($spec = $specialites_result->fetch_assoc()): ?>
                    <option value="<?= htmlspecialchars($spec['specialite']) ?>" <?= ($selected_specialite == $spec['specialite']) ? 'selected' : '' ?>>
                        <?= htmlspecialchars($spec['specialite']) ?>
                    </option>
                <?php endwhile; ?>
            </select>
        </div>
        <div class="col-md-4">
            <select name="ville" class="form-select" onchange="document.getElementById('filtreForm').submit()">
                <option value="">-- Toutes les villes --</option>
                <?php while ($ville = $villes_result->fetch_assoc()): ?>
                    <option value="<?= htmlspecialchars($ville['ville']) ?>" <?= ($selected_ville == $ville['ville']) ? 'selected' : '' ?>>
                        <?= htmlspecialchars($ville['ville']) ?>
                    </option>
                <?php endwhile; ?>
            </select>
        </div>
    </form>

    <div class="row">
        <?php if ($result->num_rows > 0): ?>
            <?php while ($row = $result->fetch_assoc()): 
                $recent = strtotime($row['created_at']) >= strtotime('-7 days'); ?>
                <div class="col-md-4 mb-4">
                    <div class="card text-center <?= $row['badge_verifie'] ? 'verified' : '' ?>">
                        <img src="<?= !empty($row['photo']) ? $row['photo'] : 'uploads/default.jpg' ?>" class="profile-img shadow-sm" alt="Photo">
                        <h5 class="mb-1">
                            <?= htmlspecialchars($row['nom']); ?>
                            <?php if ($row['badge_verifie']): ?>
                                <i class="fas fa-check-circle text-success ms-1" title="Vérifié"></i>
                                <span class="badge-verified">Vérifié</span>
                            <?php endif; ?>
                            <?php if ($recent): ?>
                                <span class="badge bg-info text-white ms-2">🆕 Nouvel inscrit</span>
                            <?php endif; ?>
                        </h5>
                        <p class="text-muted small">
                            <?= !empty($row['presentation']) ? htmlspecialchars(substr($row['presentation'], 0, 100)) . '...' : "Aucune description"; ?>
                        </p>
                        <div class="d-grid gap-2 mt-3">
                            <a href="view_profile.php?id=<?= $row['id']; ?>" class="btn btn-outline-secondary">👤 Voir Profil</a>
                            <a href="services_prestataire.php?id=<?= $row['id']; ?>" class="btn btn-pro text-white">🛠 Accéder à ses Services</a>
                            <a href="services_prestataire.php?id=<?= $row['id']; ?>#reserver" class="btn btn-success">📅 Réserver directement</a>
                        </div>
                    </div>
                </div>
            <?php endwhile; ?>
        <?php else: ?>
            <div class="alert alert-info text-center">Aucun prestataire trouvé pour les filtres sélectionnés.</div>
        <?php endif; ?>
    </div>
</div>

<?php include 'footer.php'; ?>
</body>
</html>