<?php
include 'config.php';
require 'vendor/autoload.php'; // Chargement de PHPMailer

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $nom = $_POST['nom'];
    $email = $_POST['email'];
    $password = password_hash($_POST['password'], PASSWORD_DEFAULT);
    $type = $_POST['type'];
    $token = bin2hex(random_bytes(50)); // Générer un token unique
    $statut = 'inactif'; // Compte inactif jusqu'à confirmation

    // Vérifier si l'email existe déjà
    $check_email = $conn->prepare("SELECT id FROM utilisateurs WHERE email = ?");
    $check_email->bind_param("s", $email);
    $check_email->execute();
    $check_email->store_result();

    if ($check_email->num_rows > 0) {
        $message = "<div class='alert alert-danger'>Cet email est déjà utilisé.</div>";
    } else {
        // Insérer l'utilisateur en attente de validation
        $stmt = $conn->prepare("INSERT INTO utilisateurs (nom, email, password, type, statut, token) VALUES (?, ?, ?, ?, ?, ?)");
        $stmt->bind_param("ssssss", $nom, $email, $password, $type, $statut, $token);

        if ($stmt->execute()) {
            // Envoi de l'email de confirmation avec PHPMailer
            $mail = new PHPMailer(true);
            try {
                $mail->isSMTP();
                $mail->Host = 'smtp.office365.com';
                $mail->SMTPAuth = true;
                $mail->Username = 'welid.benjanet@nabeul.r-iset.tn';
                $mail->Password = 'Walid-2019'; // Remplacez par votre mot de passe ou mot de passe d'application
                $mail->SMTPSecure = PHPMailer::ENCRYPTION_STARTTLS;
                $mail->Port = 587;

                $mail->setFrom('welid.benjanet@nabeul.r-iset.tn', 'ProBooker');
                $mail->addAddress($email, $nom);
                $mail->Subject = 'Confirmation de votre inscription - ProBooker';
                $mail->isHTML(true);
                $mail->Body = "
                    <html>
                    <head>
                        <title>Confirmation de votre compte</title>
                    </head>
                    <body>
                        <h2>Bienvenue sur ProBooker, $nom !</h2>
                        <p>Cliquez sur le lien ci-dessous pour activer votre compte :</p>
                        <a href='http://localhost/Consulting-School/confirm.php?email=".urlencode($email)."&token=".$token."' 
                            style='background-color:#ff7e5f;color:#fff;padding:10px 20px;text-decoration:none;border-radius:5px;'>
                            Activer mon compte
                        </a>
                        <p>Si vous n'avez pas demandé cette inscription, ignorez cet email.</p>
                    </body>
                    </html>
                ";

                $mail->send();
                $message = "<div class='alert alert-success'>Un email de confirmation a été envoyé. Vérifiez votre boîte mail.</div>";
            } catch (Exception $e) {
                $message = "<div class='alert alert-danger'>Erreur lors de l'envoi de l'email : {$mail->ErrorInfo}</div>";
            }
        } else {
            $message = "<div class='alert alert-danger'>Erreur lors de l'inscription.</div>";
        }
        $stmt->close();
    }
    $check_email->close();
}
$conn->close();
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <title>Inscription | ProBooker</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            height: 100vh;
            background: linear-gradient(to right, #ff7e5f, #feb47b);
        }
        .card {
            border-radius: 10px;
            box-shadow: 0px 4px 10px rgba(0, 0, 0, 0.2);
        }
        .sidebar {
            background: #fff;
            border-radius: 10px;
            padding: 30px;
        }
        .logo {
            font-size: 1.8rem;
            font-weight: bold;
            color: #ff7e5f;
        }
    </style>
</head>
<body class="d-flex justify-content-center align-items-center">
    <div class="container">
        <div class="row justify-content-center">
            <div class="col-md-10">
                <div class="card p-4">
                    <div class="row">
                        <div class="col-md-6 sidebar text-center">
                            <h2 class="logo">ProBooker</h2>
                            <p>Inscrivez-vous pour trouver des prestataires de services ou proposer les vôtres.</p>
                            <img src="img1.png" class="img-fluid mt-3 rounded">
                        </div>
                        <div class="col-md-6">
                            <h2 class="mb-4">Inscription</h2>
                            <?php if (isset($message)) echo $message; ?>
                            <form action="register.php" method="post">
                                <div class="mb-3">
                                    <label class="form-label">Nom :</label>
                                    <input type="text" name="nom" class="form-control" required>
                                </div>
                                <div class="mb-3">
                                    <label class="form-label">Email :</label>
                                    <input type="email" name="email" class="form-control" required>
                                </div>
                                <div class="mb-3">
                                    <label class="form-label">Mot de passe :</label>
                                    <input type="password" name="password" class="form-control" required>
                                </div>
                                <div class="mb-3">
                                    <label class="form-label">Type :</label>
                                    <select name="type" class="form-control">
                                        <option value="client">Client</option>
                                        <option value="prestataire">Prestataire</option>
                                    </select>
                                </div>
                                <button type="submit" class="btn btn-primary w-100">S'inscrire</button>
                                <p class="mt-3 text-center"><a href="login.php">Déjà un compte ? Connectez-vous</a></p>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</body>
</html>
