<?php
session_start();
include 'config.php';
include 'header.php';
include 'sidebar.php';

if (!isset($_SESSION['id']) || $_SESSION['type'] !== 'client') {
    header("Location: login.php");
    exit();
}

$client_id = $_SESSION['id'];

// Filtres de recherche
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$statut_filter = isset($_GET['statut']) ? $_GET['statut'] : '';

$query = "SELECT r.id, r.date_reservation, r.statut, s.nom_service, s.lieu, s.prix, u.nom AS prestataire_nom
          FROM reservations r
          JOIN services s ON r.service_id = s.id
          JOIN utilisateurs u ON s.prestataire_id = u.id
          WHERE r.client_id = ?";

$params = [$client_id];
$types = "i";

if (!empty($search)) {
    $query .= " AND (s.nom_service LIKE ? OR u.nom LIKE ?)";
    $search_param = "%$search%";
    $params[] = $search_param;
    $params[] = $search_param;
    $types .= "ss";
}

if (!empty($statut_filter)) {
    $query .= " AND r.statut = ?";
    $params[] = $statut_filter;
    $types .= "s";
}

$query .= " ORDER BY r.date_reservation DESC";

$stmt = $conn->prepare($query);
$stmt->bind_param($types, ...$params);
$stmt->execute();
$reservations = $stmt->get_result();
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <title>Mes Réservations | ProBooker</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .statut-badge {
            font-weight: bold;
            padding: 4px 10px;
            border-radius: 20px;
        }
        .badge-valide { background-color: #198754; color: white; }
        .badge-refuse { background-color: #dc3545; color: white; }
        .badge-attente { background-color: #ffc107; color: black; }
        .badge-negociation { background-color: #0dcaf0; color: black; }
    </style>
</head>
<body>
<div class="content p-4">
    <h2 class="mb-4 text-center">📋 Mes Réservations</h2>

    <form class="row mb-4" method="get">
        <div class="col-md-4">
            <input type="text" name="search" class="form-control" placeholder="Recherche service ou prestataire..." value="<?= htmlspecialchars($search) ?>">
        </div>
        <div class="col-md-4">
            <select name="statut" class="form-select">
                <option value="">-- Tous les statuts --</option>
                <option value="valider" <?= $statut_filter === 'valider' ? 'selected' : '' ?>>Validées</option>
                <option value="refuser" <?= $statut_filter === 'refuser' ? 'selected' : '' ?>>Refusées</option>
                <option value="negocier" <?= $statut_filter === 'negocier' ? 'selected' : '' ?>>En Négociation</option>
                <option value="en attente" <?= $statut_filter === 'en attente' ? 'selected' : '' ?>>En attente</option>
            </select>
        </div>
        <div class="col-md-4">
            <button type="submit" class="btn btn-primary w-100">Filtrer</button>
        </div>
    </form>

    <div class="table-responsive">
        <table class="table table-bordered table-hover align-middle text-center">
            <thead class="table-primary">
                <tr>
                    <th>Service</th>
                    <th>Prestataire</th>
                    <th>Lieu</th>
                    <th>Prix</th>
                    <th>Date</th>
                    <th>Statut</th>
                </tr>
            </thead>
            <tbody>
            <?php if ($reservations->num_rows > 0): ?>
                <?php while ($row = $reservations->fetch_assoc()): ?>
                    <?php
                        $statut = strtolower(trim($row['statut']));
                        $class = '';
                        $libelle = '';
                        switch ($statut) {
                            case 'valider': $class = 'badge-valide'; $libelle = 'Validée'; break;
                            case 'refuser': $class = 'badge-refuse'; $libelle = 'Refusée'; break;
                            case 'negocier': $class = 'badge-negociation'; $libelle = 'En Négociation'; break;
                            default: $class = 'badge-attente'; $libelle = 'En Attente'; break;
                        }
                    ?>
                    <tr>
                        <td><?= htmlspecialchars($row['nom_service']) ?></td>
                        <td><?= htmlspecialchars($row['prestataire_nom']) ?></td>
                        <td><?= htmlspecialchars($row['lieu']) ?></td>
                        <td><?= number_format($row['prix'], 2, ',', ' ') ?> €</td>
                        <td>
                            <?= !empty($row['date_reservation']) ? date("d/m/Y H:i", strtotime($row['date_reservation'])) : '<span class="text-muted">Non précisé</span>' ?>
                        </td>
                        <td><span class="statut-badge <?= $class ?>"><?= $libelle ?></span></td>
                    </tr>
                <?php endwhile; ?>
            <?php else: ?>
                <tr><td colspan="6" class="text-muted">Aucune réservation trouvée.</td></tr>
            <?php endif; ?>
            </tbody>
        </table>
    </div>
</div>
<?php include 'footer.php'; ?>
</body>
</html>
