<?php
session_start();
include 'config.php';

if (!isset($_SESSION['id']) || $_SESSION['type'] !== 'prestataire') {
    header("Location: login.php");
    exit();
}

$prestataire_id = $_SESSION['id'];

// ✅ Traitement des actions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $reservation_id = intval($_POST['reservation_id']);
    $action = $_POST['action'];

    // Vérification que la réservation appartient bien au prestataire connecté
    $verif = $conn->prepare("
        SELECT s.prestataire_id
        FROM reservations r
        JOIN services s ON r.service_id = s.id
        WHERE r.id = ?
    ");
    $verif->bind_param("i", $reservation_id);
    $verif->execute();
    $result_check = $verif->get_result();
    $verif_row = $result_check->fetch_assoc();
    $verif->close();

    if ($verif_row && $verif_row['prestataire_id'] == $prestataire_id) {
        if (in_array($action, ['valider', 'refuser'])) {
            $stmt = $conn->prepare("UPDATE reservations SET statut = ? WHERE id = ?");
            $stmt->bind_param("si", $action, $reservation_id);
            $stmt->execute();
            $stmt->close();
        } elseif ($action === 'negocier') {
            header("Location: discussion.php?reservation_id=" . $reservation_id);
            exit();
        }
    }
}

// ✅ Ensuite affichage
include 'header.php';
include 'sidebar.php';

// Récupération des réservations
$query = "
    SELECT r.*, s.nom_service, u.nom AS client_nom
    FROM reservations r
    JOIN services s ON r.service_id = s.id
    JOIN utilisateurs u ON r.client_id = u.id
    WHERE s.prestataire_id = ?
    ORDER BY r.date_reservation DESC
";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $prestataire_id);
$stmt->execute();
$result = $stmt->get_result();
?>

<div class="container mt-4">
    <div class="d-flex justify-content-between align-items-center mb-3">
        <h3 class="mb-0">📋 Mes Réservations</h3>
        <button class="btn btn-outline-primary btn-sm" onclick="location.reload()">🔄 Recharger</button>
    </div>

    <div class="table-responsive">
        <table class="table table-bordered table-hover align-middle">
            <thead class="table-light">
                <tr>
                    <th>#</th>
                    <th>Client</th>
                    <th>Service</th>
                    <th>Date</th>
                    <th>Heure</th>
                    <th>Statut</th>
                    <th>Action</th>
                </tr>
            </thead>
            <tbody>
            <?php while ($row = $result->fetch_assoc()): ?>
                <tr>
                    <td><?= $row['id'] ?></td>
                    <td><?= htmlspecialchars($row['client_nom']) ?></td>
                    <td><?= htmlspecialchars($row['nom_service']) ?></td>
                    <td><?= !empty($row['date_reservation']) ? date("d/m/Y", strtotime($row['date_reservation'])) : '—' ?></td>
                    <td><?= !empty($row['heure']) ? date("H:i", strtotime($row['heure'])) : '—' ?></td>
                    <td>
                        <span class="badge bg-<?= 
                            $row['statut'] === 'valider' ? 'success' : 
                            ($row['statut'] === 'refuser' ? 'danger' : 'warning'
                        ) ?>">
                            <?= ucfirst($row['statut']) ?>
                        </span>
                    </td>
                    <td>
                        <form method="post" class="d-flex gap-1">
                            <input type="hidden" name="reservation_id" value="<?= $row['id'] ?>">
                            <button name="action" value="valider" class="btn btn-success btn-sm">✔ Valider</button>
                            <button name="action" value="refuser" class="btn btn-danger btn-sm">✖ Refuser</button>
                            <button name="action" value="negocier" class="btn btn-warning btn-sm">💬 Négocier</button>
                        </form>
                    </td>
                </tr>
            <?php endwhile; ?>
            </tbody>
        </table>
    </div>
</div>

<script>
// 🔁 Rechargement automatique toutes les 60 secondes
setInterval(() => {
    location.reload();
}, 60000);
</script>

<?php include 'footer.php'; ?>
