<?php
session_start();
include 'config.php';

if (!isset($_SESSION['id']) || $_SESSION['type'] !== 'client') {
    header("Location: login.php");
    exit();
}

$client_id = $_SESSION['id'];
$service_id = $_GET['id'] ?? null;

if (!$service_id) {
    echo "Service non spécifié.";
    exit();
}

// Récupérer les infos du service + prestataire
$query = "SELECT s.*, u.nom AS prestataire_nom, u.id AS prestataire_id
          FROM services s
          JOIN utilisateurs u ON s.prestataire_id = u.id
          WHERE s.id = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $service_id);
$stmt->execute();
$service = $stmt->get_result()->fetch_assoc();

if (!$service) {
    echo "Service introuvable.";
    exit();
}

$prestataire_id = $service['prestataire_id'];

// Récupérer les créneaux disponibles
$disponibilites = $conn->query("SELECT id, date_debut, date_fin, statut FROM disponibilites 
                                WHERE prestataire_id = $prestataire_id 
                                AND date_debut > NOW()
                                ORDER BY date_debut ASC");

if ($_SERVER["REQUEST_METHOD"] === "POST") {
    $creneau_id = $_POST['creneau_id'];

    // Insérer la réservation
    $stmt = $conn->prepare("INSERT INTO reservations (client_id, service_id, creneau_id) VALUES (?, ?, ?)");
    $stmt->bind_param("iii", $client_id, $service_id, $creneau_id);
    if ($stmt->execute()) {
        $success = "Réservation effectuée avec succès.";
    } else {
        $error = "Erreur lors de la réservation.";
    }
}
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <title>Réserver - <?= htmlspecialchars($service['nom_service']) ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body class="bg-light">
<div class="container mt-5">
    <h2 class="mb-3"><?= htmlspecialchars($service['nom_service']) ?> - <small class="text-muted"><?= $service['lieu'] ?></small></h2>
    <p class="mb-1"><b>Prestataire :</b> <a href="view_profile.php?id=<?= $prestataire_id ?>" class="text-decoration-none text-primary"><?= htmlspecialchars($service['prestataire_nom']) ?></a></p>
    <p><b>Description :</b> <?= nl2br(htmlspecialchars($service['description'])) ?></p>
    <p><b>Prix :</b> <?= number_format($service['prix'], 2, ',', ' ') ?> €</p>

    <?php if (isset($success)) echo "<div class='alert alert-success'>$success</div>"; ?>
    <?php if (isset($error)) echo "<div class='alert alert-danger'>$error</div>"; ?>

    <form method="POST" class="card p-3 mt-4 shadow">
        <h5>📅 Choisir un créneau disponible</h5>
        <div class="mb-3">
            <label class="form-label">Créneau :</label>
            <select name="creneau_id" class="form-select" required>
                <option value="">-- Sélectionner --</option>
                <?php while ($row = $disponibilites->fetch_assoc()): ?>
                    <option value="<?= $row['id'] ?>">
                        <?= date("d/m/Y H:i", strtotime($row['date_debut'])) ?> - <?= date("H:i", strtotime($row['date_fin'])) ?> (<?= ucfirst($row['statut']) ?>)
                    </option>
                <?php endwhile; ?>
            </select>
        </div>
        <button type="submit" class="btn btn-primary">Réserver ce service</button>
    </form>
</div>
</body>
</html>
