<?php
session_start();
include 'config.php';

if (!isset($_SESSION['id'])) {
    header("Location: login.php");
    exit();
}

if (!isset($_GET['id'])) {
    echo "<p class='text-danger text-center mt-4'>Aucun prestataire sélectionné.</p>";
    exit();
}

$prestataire_id = intval($_GET['id']);

// Récupération des infos du prestataire
$prestataire = $conn->query("SELECT nom FROM utilisateurs WHERE id = $prestataire_id")->fetch_assoc();
$nom_prestataire = $prestataire ? $prestataire['nom'] : "Prestataire inconnu";

// Pagination
$limit = 6;
$page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;
$offset = ($page - 1) * $limit;

// Nombre total de services
$total_services_result = $conn->query("SELECT COUNT(*) as total FROM services WHERE prestataire_id = $prestataire_id");
$total_services = $total_services_result->fetch_assoc()['total'];
$total_pages = ceil($total_services / $limit);

// Récupération des services avec pagination
$sql = "SELECT * FROM services WHERE prestataire_id = $prestataire_id ORDER BY created_at DESC LIMIT $limit OFFSET $offset";
$result = $conn->query($sql);
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <title>Services de <?= htmlspecialchars($nom_prestataire); ?> | ProBooker</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body { background-color: #f8f9fa; }
        .card {
            border-radius: 10px;
            transition: 0.3s;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
        }
        .card:hover { transform: scale(1.02); }
        .btn-purple {
            background-color: #764ba2;
            color: white;
            border: none;
        }
        .btn-purple:hover {
            background-color: #5a3c80;
            color: white;
        }
        .pagination .page-link {
            color: #764ba2;
        }
        .pagination .page-link.active,
        .pagination .active > .page-link {
            background-color: #764ba2;
            border-color: #764ba2;
            color: white;
        }
    </style>
</head>
<body>
<div class="container mt-4">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h3>📋 Services de <a href="view_profile.php?id=<?= $prestataire_id ?>" class="text-decoration-none text-primary"><?= htmlspecialchars($nom_prestataire); ?></a></h3>
        <a href="prestataires.php" class="btn btn-secondary">← Retour à la liste</a>
    </div>

    <?php if ($result->num_rows > 0): ?>
        <div class="row">
            <?php while ($row = $result->fetch_assoc()): ?>
                <div class="col-md-4 mb-4">
                    <div class="card p-3 h-100">
                        <h5 class="text-primary"><?= htmlspecialchars($row['nom_service']); ?></h5>
                        <p><b>Lieu :</b> <?= htmlspecialchars($row['lieu']); ?></p>
                        <p><b>Prix :</b> <?= number_format($row['prix'], 2, ',', ' ') ?> €</p>
                        <p class="text-muted"><?= nl2br(htmlspecialchars($row['description'])); ?></p>
                        <a href="reserver_service.php?id=<?= $row['id'] ?>" class="btn btn-purple mt-auto w-100">Réserver</a>
                    </div>
                </div>
            <?php endwhile; ?>
        </div>

        <!-- Pagination -->
        <?php if ($total_pages > 1): ?>
            <nav aria-label="Pagination">
                <ul class="pagination justify-content-center">
                    <?php for ($i = 1; $i <= $total_pages; $i++): ?>
                        <li class="page-item <?= ($i == $page) ? 'active' : '' ?>">
                            <a class="page-link" href="?id=<?= $prestataire_id ?>&page=<?= $i ?>"><?= $i ?></a>
                        </li>
                    <?php endfor; ?>
                </ul>
            </nav>
        <?php endif; ?>

    <?php else: ?>
        <p class="text-muted">Aucun service publié par ce prestataire pour le moment.</p>
    <?php endif; ?>
</div>
</body>
</html>
