<?php
include 'config.php';

$non_lus = 0;
$reservations_en_attente = 0;
$nom_utilisateur = $_SESSION['nom'] ?? '';
$type = $_SESSION['type'] ?? '';

if (isset($_SESSION['id'])) {
    $user_id = $_SESSION['id'];

    // 🔔 Messages non lus
    $stmt = $conn->prepare("SELECT COUNT(*) FROM messages WHERE destinataire_id = ? AND lu = 0");
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $stmt->bind_result($non_lus);
    $stmt->fetch();
    $stmt->close();

    // 📅 Réservations en attente (prestataire uniquement)
    if ($type === 'prestataire') {
        $stmt = $conn->prepare("
            SELECT COUNT(*) 
            FROM reservations r
            JOIN services s ON r.service_id = s.id
            WHERE s.prestataire_id = ? AND r.statut = 'en attente'
        ");
        $stmt->bind_param("i", $user_id);
        $stmt->execute();
        $stmt->bind_result($reservations_en_attente);
        $stmt->fetch();
        $stmt->close();
    }
}
?>

<link rel="stylesheet" href="sidebar_styles.css">

<div class="d-flex">
    <!-- ✅ Sidebar -->
    <div class="sidebar-custom d-flex flex-column">
        <div class="sidebar-title text-center text-primary fw-bold mb-4">
            Espace<br><span class="text-break"><?= htmlspecialchars($nom_utilisateur) ?></span>
        </div>

        <ul class="nav flex-column">
            <li class="nav-item">
                <a href="<?= $type === 'prestataire' ? 'dashboard_prestataire.php' : 'dashboard_client.php' ?>" class="nav-link">
                    <i class="fas fa-home me-2"></i> Accueil
                </a>
            </li>

            <?php if ($type === 'prestataire'): ?>
                <li class="nav-item"><a href="profile.php" class="nav-link"><i class="fas fa-user-edit me-2"></i> Modifier Profil</a></li>
                <li class="nav-item"><a href="view_profile.php" class="nav-link"><i class="fas fa-eye me-2"></i> Voir Profil</a></li>
                <li class="nav-item"><a href="disponibilites.php" class="nav-link"><i class="fas fa-calendar me-2"></i> Mes Disponibilités</a></li>
                <li class="nav-item"><a href="badge_verification.php" class="nav-link"><i class="fas fa-certificate me-2"></i> Obtenir Badge</a></li>

                <li class="nav-item">
                    <a class="nav-link collapsed" data-bs-toggle="collapse" href="#servicesMenu" role="button">
                        <i class="fas fa-briefcase me-2"></i> Services <i class="fas fa-chevron-down float-end"></i>
                    </a>
                    <ul class="collapse list-unstyled ms-3" id="servicesMenu">
                        <li><a href="ajouter_service.php" class="nav-link">➕ Ajouter un Service</a></li>
                        <li><a href="mes_services.php" class="nav-link">📋 Mes Services</a></li>
                    </ul>
                </li>

                <li class="nav-item">
                    <a href="reservations_prestataire.php" class="nav-link">
                        <i class="fas fa-calendar-check me-2"></i> Réservations
                        <?php if ($reservations_en_attente > 0): ?>
                            <span class="badge bg-danger ms-2" id="reservation-badge"><?= $reservations_en_attente ?></span>
                        <?php endif; ?>
                    </a>
                </li>
            <?php else: ?>
                <li class="nav-item"><a href="prestataires.php" class="nav-link"><i class="fas fa-search me-2"></i> Trouver Prestataire</a></li>
                <li class="nav-item"><a href="reservations_client.php" class="nav-link"><i class="fas fa-calendar me-2"></i> Mes Réservations</a></li>
            <?php endif; ?>

            <li class="nav-item">
                <a href="messagerie.php" class="nav-link">
                    <i class="fas fa-envelope me-2"></i> Messagerie
                    <?php if ($non_lus > 0): ?>
                        <span class="badge bg-danger ms-2" id="message-badge"><?= $non_lus ?></span>
                    <?php endif; ?>
                </a>
            </li>
        </ul>

        <div class="mt-auto text-center">
            <a href="logout.php" class="btn btn-danger w-100 fw-bold mt-4">
                <i class="fas fa-sign-out-alt"></i> Déconnexion
            </a>
        </div>
    </div>

    <!-- ✅ Contenu principal -->
    <div class="content p-4" style="width: 100%;">
