<?php
session_start(); 
include 'header.php';
include 'sidebar.php';

if (!isset($_SESSION['id'])) {
    header("Location: login.php");
    exit();
}

include 'config.php';

$prestataire_id = isset($_GET['id']) ? intval($_GET['id']) : $_SESSION['id'];
$result = $conn->query("SELECT nom, email, presentation, cv_path, photo, specialite, pays, ville, telephone, site_web, badge_verifie FROM utilisateurs WHERE id = $prestataire_id");
$user_data = $result->fetch_assoc();

if (!$user_data) {
    echo "<p class='alert alert-danger text-center'>Profil introuvable.</p>";
    exit();
}

extract($user_data);

$medias = $conn->query("SELECT * FROM realisations WHERE prestataire_id = $prestataire_id ORDER BY date_upload DESC");
$conn->close();
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <title>Profil Prestataire | ProBooker</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <script src="https://kit.fontawesome.com/a076d05399.js" crossorigin="anonymous"></script>
    <link rel="stylesheet" href="styles.css">
    <style>
        .verified-badge {
            font-size: 18px;
            color: #1da1f2;
            margin-left: 8px;
        }
        .verified-banner {
            background-color: #e6f2ff;
            color: #0d6efd;
            font-weight: bold;
            padding: 5px 10px;
            border-radius: 8px;
            display: inline-block;
            margin-top: 10px;
        }
    </style>
</head>
<body>
<div class="container mt-4">
    <div class="row">
        <!-- Infos prestataire -->
        <div class="col-lg-4 mb-4">
            <div class="card text-center p-4 shadow-sm">
                <h3 class="text-primary">
                    <i class="fas fa-user"></i> <?= strtoupper(htmlspecialchars($nom)); ?>
                    <?php if ($badge_verifie): ?>
                        <i class="fas fa-check-circle verified-badge" title="Prestataire vérifié"></i>
                    <?php endif; ?>
                </h3>
                <img src="<?= !empty($photo) ? $photo : 'uploads/default.jpg' ?>" class="profile-img">
                <p class="mt-2"><b>Spécialité :</b> <?= htmlspecialchars($specialite ?: 'Non renseignée'); ?></p>
                <p><b>Localisation :</b> <?= htmlspecialchars(trim($pays . ', ' . $ville) ?: 'Non renseignée'); ?></p>
                <?php if ($badge_verifie): ?>
                    <div class="verified-banner">
                        ✅ Prestataire Vérifié
                    </div>
                <?php endif; ?>
            </div>

            <div class="card p-3 mt-3 shadow-sm">
                <h5 class="text-secondary"><i class="fas fa-phone"></i> Contact</h5>
                <p><b>Email :</b> <?= htmlspecialchars($email); ?></p>
                <p><b>Téléphone :</b> <?= htmlspecialchars($telephone ?: 'Non renseigné'); ?></p>
                <p><b>Site Web :</b> <?= !empty($site_web) ? "<a href='$site_web' target='_blank' class='text-primary'>Visiter</a>" : 'Non renseigné'; ?></p>
            </div>

            <div class="card p-3 mt-3 shadow-sm">
                <h5 class="text-secondary"><i class="fas fa-file"></i> Mon CV</h5>
                <?php if ($cv_path): ?>
                    <a href="<?= $cv_path ?>" target="_blank" class="btn btn-outline-primary w-100">
                        <i class="fas fa-folder-open"></i> Voir mon CV
                    </a>
                <?php else: ?>
                    <p class="text-muted">Aucun CV ajouté.</p>
                <?php endif; ?>
            </div>
        </div>

        <!-- À propos & Réalisations -->
        <div class="col-lg-8">
            <div class="card p-4 shadow-sm">
                <h4 class="text-primary"><i class="fas fa-info-circle"></i> À propos</h4>
                <p class="about-section"> <?= nl2br(htmlspecialchars_decode($presentation)); ?> </p>
            </div>

            <ul class="nav nav-tabs mt-3" id="profilTabs" role="tablist">
                <li class="nav-item" role="presentation">
                    <button class="nav-link active" id="photos-tab" data-bs-toggle="tab" data-bs-target="#photos" type="button" role="tab">📷 Photos</button>
                </li>
                <li class="nav-item" role="presentation">
                    <button class="nav-link" id="videos-tab" data-bs-toggle="tab" data-bs-target="#videos" type="button" role="tab">🎥 Vidéos</button>
                </li>
            </ul>
            <div class="tab-content p-3 border shadow-sm" id="profilTabsContent">
                <div class="tab-pane fade show active" id="photos" role="tabpanel">
                    <div class="row g-3">
                        <?php while ($row = $medias->fetch_assoc()): ?>
                            <?php if ($row['type'] == 'photo'): ?>
                                <div class="col-sm-6 col-md-4">
                                    <img src="<?= $row['file_path']; ?>" class="img-fluid rounded shadow-sm">
                                    <p class="text-muted mt-2"><?= htmlspecialchars($row['description']); ?></p>
                                </div>
                            <?php endif; ?>
                        <?php endwhile; ?>
                    </div>
                </div>

                <div class="tab-pane fade" id="videos" role="tabpanel">
                    <div class="row g-3">
                        <?php
                        $medias->data_seek(0);
                        while ($row = $medias->fetch_assoc()):
                            if ($row['type'] == 'video'):
                                $isYouTube = !empty($row['video_url']);
                                $videoUrl = '';

                                if ($isYouTube) {
                                    parse_str(parse_url($row['video_url'], PHP_URL_QUERY), $urlParams);
                                    $videoId = $urlParams['v'] ?? '';
                                    $videoUrl = $videoId ? "https://www.youtube.com/embed/" . htmlspecialchars($videoId) : htmlspecialchars($row['video_url']);
                                }
                        ?>
                            <div class="col-sm-12 col-md-6">
                                <div class="card shadow-sm p-2">
                                    <?php if ($isYouTube && $videoUrl): ?>
                                        <div class="ratio ratio-16x9">
                                            <iframe src="<?= $videoUrl ?>" frameborder="0" allowfullscreen></iframe>
                                        </div>
                                    <?php else: ?>
                                        <video controls class="w-100 rounded">
                                            <source src="<?= htmlspecialchars($row['file_path']) ?>" type="video/mp4">
                                            Votre navigateur ne supporte pas la vidéo.
                                        </video>
                                    <?php endif; ?>
                                    <p class="text-muted mt-2"><?= htmlspecialchars($row['description']) ?></p>
                                </div>
                            </div>
                        <?php endif; endwhile; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<?php include 'footer.php'; ?>
</body>
</html>

